bpw\_pde package
================

Module contents
---------------

.. automodule:: bpw_pde
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

bpw\_pde.common module
----------------------

.. automodule:: bpw_pde.common
   :members:
   :undoc-members:
   :show-inheritance:

bpw\_pde.dataframe module
-------------------------

.. automodule:: bpw_pde.dataframe
   :members:
   :undoc-members:
   :show-inheritance:

bpw\_pde.index module
---------------------

.. automodule:: bpw_pde.index
   :members:
   :undoc-members:
   :show-inheritance:

bpw\_pde.series module
----------------------

.. automodule:: bpw_pde.series
   :members:
   :undoc-members:
   :show-inheritance:
